@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: aeson-pretty
 version: 0.7.2
-id: aeson-pretty-0.7.2-f96010a8b5a789161d9ab7da8647359f
-key: aeson_43KdGwKRpIoGPAz4iGL21O
+id: aeson-pretty-0.7.2-38276a5fbe9d416306eeea651da7225e
+key: aeson_7xMcRIYqZ2zKl5sq1hVrNK
 license: BSD3
 copyright: Copyright 2011 Falko Peters
 maintainer: Falko Peters <falko.peters@gmail.com>
@@ -34,9 +34,9 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/aeson-pretty-0.7.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/aeson-pretty-0.7.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/aeson-pretty-0.7.2
-hs-libraries: HSaeson-pretty-0.7.2-43KdGwKRpIoGPAz4iGL21O
+hs-libraries: HSaeson-pretty-0.7.2-7xMcRIYqZ2zKl5sq1hVrNK
 depends:
-    aeson-0.11.0.0-3b69ab8a9952fc7c94fde12b431d717b
+    aeson-0.11.1.0-9c8ef4d36b55b55b3762b9041f2dfc23
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
